@@ -3,6 +3,3 @@ require "support/minitest-patch"
 require "minitest/autorun"
 require "cabin"
 require "stringio"
-require "simplecov"
-
-SimpleCov.start
